@@ -1,6 +1,6 @@
 package NewsML_G2_Test_Helpers;
 
-# $Id: NewsML_G2_Test_Helpers.pm 57048 2014-10-15 15:31:35Z apatechrdlicka $
+# $Id: NewsML_G2_Test_Helpers.pm 57138 2014-10-17 07:21:20Z apatecgortan $
 
 use Exporter 'import';
 use File::Spec::Functions qw(catfile);
@@ -113,16 +113,20 @@ our @keywords = qw(beer vienna prater kolarik schweizerhaus);
 
 sub validate_g2 {
     my ($dom, $version) = @_;
-    $version =~ s/\./_/;
 
-    my $xsd = catfile('t', 'xsds', "NewsML-G2_$version-spec-All-Power.xsd");
-    ok(my $xmlschema = XML::LibXML::Schema->new(location => $xsd), "parsing $version XSD");
+  SKIP: {
+        skip 'libxml2 before 2.8 reports bogus violation on children of "broader"', 2 if (20800 > XML::LibXML::LIBXML_RUNTIME_VERSION);
+        $version =~ tr/./_/;
+        my $xsd = catfile('t', 'xsds', "NewsML-G2_$version-spec-All-Power.xsd");
+        ok(my $xmlschema = XML::LibXML::Schema->new(location => $xsd), "parsing $version XSD");
 
-    lives_ok(sub {$xmlschema->validate($dom)}, "XML validates against $version XSD");
+        lives_ok(sub {$xmlschema->validate($dom)}, "XML validates against $version XSD");
+    }
 
     return;
 }
 
+
 sub _create_ni {
     my $ni_cls = shift;
     my $hash  = shift;
